Segments/Dimensional
====================

Data from dimensionalized tables, operating and geographic segments for example.  The data behind the Calcbench Segment page www.calcbench.com/segments.

.. automodule:: calcbench.dimensional
    :members:
    :undoc-members: